@@ -27,7 +27,8 @@ if __name__ == '__main__':
       from zebrazoom.getTailExtremityFirstFrame import getTailExtremityFirstFrame
       __spec__ = "ModuleSpec(name='builtins', loader=<class '_frozen_importlib.BuiltinImporter'>)"
       getTailExtremityFirstFrame(pathToVideo, videoName, videoExt, configFile, argv)
-        
+    
+    
     elif sys.argv[1] == "recreateSuperStruct":
       
       pathToVideo = sys.argv[2]
@@ -39,18 +40,43 @@ if __name__ == '__main__':
       from zebrazoom.recreateSuperStruct import recreateSuperStruct
       __spec__ = "ModuleSpec(name='builtins', loader=<class '_frozen_importlib.BuiltinImporter'>)"
       recreateSuperStruct(pathToVideo, videoName, videoExt, configFile, argv)
-        
+    
+    
     elif sys.argv[1] == "convertSeqToAvi":
       
       from zebrazoom.videoFormatConversion.seq_to_avi import sqb_convert_to_avi
       path      = sys.argv[2]
       videoName = sys.argv[3]
-      if len(sys.argv) == 5:
-        lastFrame = int(sys.argv[4])
-      else:
-        lastFrame = -1
-      sqb_convert_to_avi(path, videoName, lastFrame)
-
+      codec     = sys.argv[4] if len(sys.argv) >= 5 else 'HFYU'
+      lastFrame = int(sys.argv[5]) if len(sys.argv) >= 6 else -1
+      sqb_convert_to_avi(path, videoName, codec, lastFrame)
+    
+    
+    elif sys.argv[1] == "convertSeqToAviThenLaunchTracking":
+      
+      from zebrazoom.videoFormatConversion.seq_to_avi import sqb_convert_to_avi
+      from zebrazoom.mainZZ import mainZZ
+      from pathlib import Path
+      import time
+      path       = sys.argv[2]
+      videoName  = sys.argv[3]
+      configFile = sys.argv[4]      
+      codec      = sys.argv[5] if len(sys.argv) >= 6 else 'HFYU'
+      lastFrame  = int(sys.argv[6]) if len(sys.argv) >= 7 else -1
+      argv2      = sys.argv.copy()
+      del argv2[1:2]
+      argv2.insert(3, 'avi')
+      del argv2[5:7]
+      path2      = Path(path).parent
+      print("Launching the convertion from seq to avi")
+      sqb_convert_to_avi(path, videoName, codec, lastFrame)
+      print("small break start")
+      time.sleep(2)
+      print("Launching the tracking, the data produced by ZebraZoom can be found in the folder: " + os.path.join(dir_path,'ZZoutput'))
+      __spec__ = "ModuleSpec(name='builtins', loader=<class '_frozen_importlib.BuiltinImporter'>)"
+      mainZZ(path2, videoName, 'avi', configFile, argv2)
+    
+    
     elif sys.argv[1] == "dataPostProcessing":
       
       if sys.argv[2] == "sleepVsMoving":
@@ -59,21 +85,22 @@ if __name__ == '__main__':
         videoName      = sys.argv[3]
         speedThresholdForMoving = float(sys.argv[4])
         notMovingNumberOfFramesThresholdForSleep = int(sys.argv[5])
-        if len(sys.argv) >= 7:
-         specifiedStartTime  = sys.argv[6]
+        maxDistBetweenTwoPointsInsideSleepingPeriod = float(sys.argv[6]) if len(sys.argv) >= 7 else -1
+        if len(sys.argv) >= 8:
+         specifiedStartTime  = sys.argv[7]
         else:
           specifiedStartTime = 0
-        if len(sys.argv) >= 8:
-          distanceTravelledRollingMedianFilter = int(sys.argv[7])
+        if len(sys.argv) >= 9:
+          distanceTravelledRollingMedianFilter = int(sys.argv[8])
         else:
           distanceTravelledRollingMedianFilter = 0
-        if len(sys.argv) >= 10:
-          videoPixelSize = float(sys.argv[8])
-          videoFPS = float(sys.argv[9])
+        if len(sys.argv) >= 11:
+          videoPixelSize = float(sys.argv[9])
+          videoFPS = float(sys.argv[10])
         else:
           videoPixelSize = -1
           videoFPS = -1
-        calculateSleepVsMovingPeriods(pathToZZoutput, videoName, speedThresholdForMoving, notMovingNumberOfFramesThresholdForSleep, specifiedStartTime, distanceTravelledRollingMedianFilter, videoPixelSize, videoFPS)
+        calculateSleepVsMovingPeriods(pathToZZoutput, videoName, speedThresholdForMoving, notMovingNumberOfFramesThresholdForSleep, maxDistBetweenTwoPointsInsideSleepingPeriod, specifiedStartTime, distanceTravelledRollingMedianFilter, videoPixelSize, videoFPS)
       
       if sys.argv[2] == "firstSleepingTimeAfterSpecifiedTime":
         from zebrazoom.code.dataPostProcessing.findSleepVsMoving import firstSleepingTimeAfterSpecifiedTime
@@ -110,6 +137,15 @@ if __name__ == '__main__':
         from zebrazoom.kinematicParametersAnalysis import kinematicParametersAnalysis
         kinematicParametersAnalysis(sys)
       
+      if sys.argv[2] == "clusteringAnalysis":
+        from zebrazoom.clusteringAnalysis import clusteringAnalysis
+        clusteringAnalysis(sys)
+        
+      if sys.argv[2] == "clusteringAnalysisPerFrame":
+        from zebrazoom.clusteringAnalysisPerFrame import clusteringAnalysisPerFrame
+        clusteringAnalysisPerFrame(sys)
+    
+    
     elif sys.argv[1] == "visualizeMovingAndSleepingTime":
       
       from zebrazoom.code.readValidationVideo import readValidationVideo
@@ -126,7 +162,8 @@ if __name__ == '__main__':
         
         framesToShow = df[["sleep_" + str(i) for i in range(0, nbWells)]].to_numpy()
         readValidationVideo("", sys.argv[3], "", -1, -1, 0, 1, framesToShow)
-        
+    
+    
     else:
       
       print("The data produced by ZebraZoom can be found in the folder: " + os.path.join(dir_path,'ZZoutput'))
