@@ -1,6 +1,7 @@
 from zebrazoom.code.dataPostProcessing.generateAllTimeTailAngleGraph import generateAllTimeTailAngleGraph
 from zebrazoom.code.dataPostProcessing.perBoutOutput import perBoutOutput
 from zebrazoom.code.dataPostProcessing.computeEyesHeadingPlot import computeEyesHeadingPlot
+from zebrazoom.code.dataPostProcessing.tailAnglesHeatmap import tailAnglesHeatMap
 
 def dataPostProcessing(outputFolderVideo, superStruct, hyperparameters, videoName):
 
@@ -12,3 +13,6 @@ def dataPostProcessing(outputFolderVideo, superStruct, hyperparameters, videoNam
   
   if hyperparameters["computeEyesHeadingPlot"]:
     computeEyesHeadingPlot(superStruct, hyperparameters, videoName)
+
+  if hyperparameters["tailAnglesHeatMap"]:
+    tailAnglesHeatMap(superStruct, hyperparameters, videoName)
\ No newline at end of file
